@@ -275,7 +275,8 @@ class ParamEditor(QtWidgets.QDockWidget):
     return paramState
 
   def saveCurStateAsDefault(self):
-    return self.saveParamValues('Default', allowOverwriteDefault=True)
+    self.saveParamValues('Default', allowOverwriteDefault=True)
+    self.stateName = 'Default'
 
   def _loadParamState(self, stateName: str, stateDict: dict=None, applyChanges=True):
     # Bug in pyqtgraph restore state doesn't play nice when parameters have connected functions outside the parameter
