@@ -118,6 +118,11 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
                                                 namePath=(owner.__groupingName__,))
 
     act.triggered.connect(proc)
+
+    # Win is provided by this plugin, so take it out of required keys if needed
+    proc.input.keysFromPrevIO.discard('win')
+    # Registration may have happened after attaching win ref, so ensure reference is valid here too
+    proc.updateInput(win=self.win, graceful=True)
     if returnParam:
       return proc, param
     return proc
