@@ -111,7 +111,7 @@ class NestedProcWrapper(CompositionMixin):
     # doubly nesting and return a reference to the created parent param or the normal one if no nesting occurred.
     # The if-branching allows this to occur
     if parentParam is None:
-      parentParam = Parameter.create(name=self.algName, type='procgroup')
+      parentParam = Parameter.create(name=self.algName, type='procgroup', process=processor)
       # Avoid doubly-nested top parameter
       self.nestHyperparams = False
     self.parentParam : GroupParameter = parentParam
