@@ -1165,13 +1165,20 @@ class DummySignal:
   """Useful for spoofing a qt connection that doesn't do anything"""
   def connect(self, *args): pass
   def disconnect(self, *args): pass
-  def emit(self, *args): pass
+  def emit(self, *args):
+    if self.capture:
+      self.emissions.append(args)
+
+  def __init__(self, capture=False):
+    self.emissions = []
+    self.capture = capture
 
 @contextlib.contextmanager
-def makeDummySignal(obj, sigName: str):
+def makeDummySignal(obj, sigName: str, capture=False):
   oldSig = getattr(obj, sigName)
   try:
-    setattr(obj, sigName, DummySignal())
-    yield
+    newSig = DummySignal(capture)
+    setattr(obj, sigName, newSig)
+    yield newSig
   finally:
     setattr(obj, sigName, oldSig)
\ No newline at end of file
